# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageIntensityPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkInvertIntensityImageFilterPython
else:
    import _itkInvertIntensityImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterBPython

def itkInvertIntensityImageFilterIF2IF2_Superclass_New():
    return itkInvertIntensityImageFilterIF2IF2_Superclass.New()

class itkInvertIntensityImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkInvertIntensityImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIF2IF2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIF2IF2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< float,float >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< float,float > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< float,float > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIF2IF2_Superclass

        Create a new object of the class itkInvertIntensityImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIF2IF2_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Superclass_swigregister(itkInvertIntensityImageFilterIF2IF2_Superclass)

def itkInvertIntensityImageFilterIF3IF3_Superclass_New():
    return itkInvertIntensityImageFilterIF3IF3_Superclass.New()

class itkInvertIntensityImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkInvertIntensityImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIF3IF3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIF3IF3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< float,float >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< float,float > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< float,float > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIF3IF3_Superclass

        Create a new object of the class itkInvertIntensityImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIF3IF3_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Superclass_swigregister(itkInvertIntensityImageFilterIF3IF3_Superclass)

def itkInvertIntensityImageFilterISS2ISS2_Superclass_New():
    return itkInvertIntensityImageFilterISS2ISS2_Superclass.New()

class itkInvertIntensityImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkInvertIntensityImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< short,short >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< short,short > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< short,short > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterISS2ISS2_Superclass

        Create a new object of the class itkInvertIntensityImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterISS2ISS2_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Superclass_swigregister(itkInvertIntensityImageFilterISS2ISS2_Superclass)

def itkInvertIntensityImageFilterISS3ISS3_Superclass_New():
    return itkInvertIntensityImageFilterISS3ISS3_Superclass.New()

class itkInvertIntensityImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkInvertIntensityImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< short,short >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< short,short > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< short,short > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterISS3ISS3_Superclass

        Create a new object of the class itkInvertIntensityImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterISS3ISS3_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Superclass_swigregister(itkInvertIntensityImageFilterISS3ISS3_Superclass)

def itkInvertIntensityImageFilterIUC2IUC2_Superclass_New():
    return itkInvertIntensityImageFilterIUC2IUC2_Superclass.New()

class itkInvertIntensityImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkInvertIntensityImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< unsigned char,unsigned char > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< unsigned char,unsigned char > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkInvertIntensityImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIUC2IUC2_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Superclass_swigregister(itkInvertIntensityImageFilterIUC2IUC2_Superclass)

def itkInvertIntensityImageFilterIUC3IUC3_Superclass_New():
    return itkInvertIntensityImageFilterIUC3IUC3_Superclass.New()

class itkInvertIntensityImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkInvertIntensityImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::InvertIntensityTransform< unsigned char,unsigned char > const &
        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::InvertIntensityTransform< unsigned char,unsigned char > const &

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkInvertIntensityImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIUC3IUC3_Superclass in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Superclass_swigregister(itkInvertIntensityImageFilterIUC3IUC3_Superclass)

def itkInvertIntensityImageFilterIF2IF2_New():
    return itkInvertIntensityImageFilterIF2IF2.New()

class itkInvertIntensityImageFilterIF2IF2(itkInvertIntensityImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIF2IF2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIF2IF2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> float const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIF2IF2

        Create a new object of the class itkInvertIntensityImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIF2IF2 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF2IF2_swigregister(itkInvertIntensityImageFilterIF2IF2)

def itkInvertIntensityImageFilterIF3IF3_New():
    return itkInvertIntensityImageFilterIF3IF3.New()

class itkInvertIntensityImageFilterIF3IF3(itkInvertIntensityImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIF3IF3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIF3IF3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> float const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIF3IF3

        Create a new object of the class itkInvertIntensityImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIF3IF3 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIF3IF3_swigregister(itkInvertIntensityImageFilterIF3IF3)

def itkInvertIntensityImageFilterISS2ISS2_New():
    return itkInvertIntensityImageFilterISS2ISS2.New()

class itkInvertIntensityImageFilterISS2ISS2(itkInvertIntensityImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterISS2ISS2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterISS2ISS2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> short const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterISS2ISS2

        Create a new object of the class itkInvertIntensityImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterISS2ISS2 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS2ISS2_swigregister(itkInvertIntensityImageFilterISS2ISS2)

def itkInvertIntensityImageFilterISS3ISS3_New():
    return itkInvertIntensityImageFilterISS3ISS3.New()

class itkInvertIntensityImageFilterISS3ISS3(itkInvertIntensityImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterISS3ISS3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterISS3ISS3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> short const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterISS3ISS3

        Create a new object of the class itkInvertIntensityImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterISS3ISS3 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterISS3ISS3_swigregister(itkInvertIntensityImageFilterISS3ISS3)

def itkInvertIntensityImageFilterIUC2IUC2_New():
    return itkInvertIntensityImageFilterIUC2IUC2.New()

class itkInvertIntensityImageFilterIUC2IUC2(itkInvertIntensityImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIUC2IUC2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIUC2IUC2_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> unsigned char const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIUC2IUC2

        Create a new object of the class itkInvertIntensityImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIUC2IUC2 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC2IUC2_swigregister(itkInvertIntensityImageFilterIUC2IUC2)

def itkInvertIntensityImageFilterIUC3IUC3_New():
    return itkInvertIntensityImageFilterIUC3IUC3.New()

class itkInvertIntensityImageFilterIUC3IUC3(itkInvertIntensityImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkInvertIntensityImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkInvertIntensityImageFilterIUC3IUC3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkInvertIntensityImageFilterIUC3IUC3_Pointer"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_Clone(self)

    def SetMaximum(self, _arg):
        r"""
        SetMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_SetMaximum(self, _arg)

    def GetMaximum(self):
        r"""GetMaximum(self) -> unsigned char const &"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_GetMaximum(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_BeforeThreadedGenerateData(self)
    InputHasNumericTraitsCheck = _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkInvertIntensityImageFilterPython.delete_itkInvertIntensityImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkInvertIntensityImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkInvertIntensityImageFilterIUC3IUC3

        Create a new object of the class itkInvertIntensityImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkInvertIntensityImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkInvertIntensityImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkInvertIntensityImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkInvertIntensityImageFilterIUC3IUC3 in _itkInvertIntensityImageFilterPython:
_itkInvertIntensityImageFilterPython.itkInvertIntensityImageFilterIUC3IUC3_swigregister(itkInvertIntensityImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def invert_intensity_image_filter(*args: itkt.ImageLike,  maximum: float=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for InvertIntensityImageFilter"""
    import itk

    kwarg_typehints = { 'maximum':maximum,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.InvertIntensityImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def invert_intensity_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.InvertIntensityImageFilter
    invert_intensity_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    invert_intensity_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__



